Change-O - Repertoire clonal assignment toolkit
================================================================================

Change-O is a collection of tools for processing the output of V(D)J alignment
tools, assigning clonal clusters to immunoglobulin (Ig) sequences, and
reconstructing germline sequences.
 
Dramatic improvements in high-throughput sequencing technologies now enable 
large-scale characterization of Ig repertoires, defined as the collection of
trans-membrane antigen-receptor proteins located on the surface of B cells and
T cells. Change-O is a suite of utilities to facilitate advanced analysis of
Ig and TCR sequences following germline segment assignment. Change-O
handles output from IMGT/HighV-QUEST and IgBLAST, and provides a wide variety of
clustering methods for assigning clonal groups to Ig sequences. Record sorting, 
grouping, and various database manipulation operations are also included.
